# Utilities for working with Softwarefabrica Django Wiki

About this document

This document describes the command-line utilities provided to work with wikis implemented using Softwarefabrica Django Wiki.

Contents

- Overview
- `sf-import-twiki`
- `sf-wiki-sync`

# Overview

The included command-line utilities are:

> - `'sf-import-twiki'`: converts a TWiki wiki into a softwarefabrica wiki
> - `'sf-wiki-sync'`: synchronizes a wiki across multiple machines

# `sf-import-twiki`

The `sf-import-twiki` command converts a TWiki wiki, importing it into a softwarefabrica wiki, along with all its attachments. Please run the utility with `--help` for more information:

    sf-import-twiki --help

# `sf-wiki-sync`

The `sf-wiki-sync` synchronizes a wiki across multiple installations. Please run the utility with `--help` for more information:

    sf-wiki-sync --help

WARNING: this utility is currently under development, and not yet ready for production use.